==> flowtask-4.7.2-cp311-cp311-manylinux_2_17_x86_64.manylinux2014_x86_64.whl: flowtask/hooks/actions/abstract.py <==
from abc import ABC, abstractmethod
from ..interfaces import LogSupport

class AbstractAction(LogSupport, ABC):
    """AbstractAction.

    Action can be used to perform operations when a Hook is called.
    """
    def __init__(self, *args, **kwargs):
        LogSupport.__init__(self, **kwargs)
        # You can define any initialization logic here, such as
        # storing parameters that control the behavior of the action.
        self._args = args
        self._kwargs = kwargs
        # program
        self._program = kwargs.pop('program', 'navigator')
        # attributes (root-level of component arguments):
        try:
            self._attributes = kwargs['attributes']
            del kwargs['attributes']
        except KeyError:
            self._attributes = {}
        try:
            self._arguments = kwargs['arguments']
            del kwargs['arguments']
        except KeyError:
            self._arguments = {}
        # Arguments of actions::
        try:
            self._arguments = {**kwargs, **self._arguments}
        except (TypeError, ValueError):
            pass
        # set the attributes of Action:
        for arg, val in self._arguments.items():
            if arg in self._attributes:
                val = self._attributes[arg]
            try:
                setattr(self, arg, val)
            except Exception as err:
                self._logger.warning(
                    f'Wrong Attribute: {arg}={val}'
                )
                self._logger.error(err)

    @abstractmethod
    async def open(self):
        pass

    @abstractmethod
    async def close(self):
        pass

    @abstractmethod
    async def run(self, *args, **kwargs):
        # This is where you define the behavior of the action.
        # Since this method is asynchronous, you can use the "await"
        # keyword to call other asynchronous functions or coroutines.
        pass

    async def __aenter__(self) -> "AbstractAction":
        await self.open()
        return self

    async def __aexit__(self, exc_type, exc_val, exc_tb) -> None:
        # clean up anything you need to clean up
        return await self.close()

==> flowtask-5.6.1-cp311-cp311-manylinux_2_17_x86_64.manylinux2014_x86_64.whl: flowtask/hooks/actions/abstract.py <==
from abc import ABC, abstractmethod
from ...interfaces import LogSupport, MaskSupport, LocaleSupport


class AbstractAction(MaskSupport, LogSupport, LocaleSupport, ABC):
    """AbstractAction.

    Action can be used to perform operations when a Hook is called.
    """

    def __init__(self, hook, *args, **kwargs):
        self._name_ = self.__class__.__name__
        self._hook_ = hook
        super().__init__(*args, **kwargs)
        # program
        self._program = kwargs.pop("program", "navigator")
        # attributes (root-level of component arguments):
        self._attributes: dict = kwargs.pop("attributes", {})
        # arguments (root-level of component arguments):
        self.arguments: dict = kwargs.pop("arguments", {})
        # Arguments of actions::
        try:
            self.arguments = {**kwargs, **self.arguments}
        except (TypeError, ValueError):
            pass
        # set the attributes of Action:
        for arg, val in self.arguments.items():
            if arg in self._attributes:
                val = self._attributes[arg]
            try:
                setattr(self, arg, val)
            except Exception as err:
                self._logger.warning(
                    f"Wrong Attribute: {arg}={val}"
                )
                self._logger.error(err)
        # You can define any initialization logic here, such as
        # storing parameters that control the behavior of the action.
        self._args = args
        self._kwargs = kwargs

    def __repr__(self):
        return f"<Action.{self._name_}>"

    @abstractmethod
    async def open(self):
        pass

    @abstractmethod
    async def close(self):
        pass

    @abstractmethod
    async def run(self, *args, **kwargs):
        # This is where you define the behavior of the action.
        # Since this method is asynchronous, you can use the "await"
        # keyword to call other asynchronous functions or coroutines.
        pass

    async def __aenter__(self) -> "AbstractAction":
        await self.open()
        return self

    async def __aexit__(self, exc_type, exc_val, exc_tb) -> None:
        # clean up anything you need to clean up
        return await self.close()
